==> estateplat-common-1.2.4-20201110.023611-494-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttFwHBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttFwH;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttFwHBdc extends KttFwH {
    private String dffwlxdm;
    private String dffwlxmc;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dfztdm;
    private String dfztmc;
    private String dfhxdm;
    private String dfhxmc;
    private String dfhxjgdm;
    private String dfhxjgmc;
    private String dffwyt1dm;
    private String dffwyt1mc;
    private String dffwyt2dm;
    private String dffwyt2mc;
    private String dffwyt3dm;
    private String dffwyt3mc;
    @XmlAttribute(
            name = "DFFWLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwlxdm() {
        return dffwlxdm;
    }

    public void setDffwlxdm(String dffwlxdm) {
        this.dffwlxdm = dffwlxdm;
    }
    @XmlTransient
    public String getDffwlxmc() {
        return dffwlxmc;
    }

    public void setDffwlxmc(String dffwlxmc) {
        this.dffwlxmc = dffwlxmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlTransient
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxzmc) {
        this.dffwxzmc = dffwxzmc;
    }
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlTransient
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
    @XmlAttribute(
            name = "DFHXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhxdm() {
        return dfhxdm;
    }

    public void setDfhxdm(String dfhxdm) {
        this.dfhxdm = dfhxdm;
    }
    @XmlTransient
    public String getDfhxmc() {
        return dfhxmc;
    }

    public void setDfhxmc(String dfhxmc) {
        this.dfhxmc = dfhxmc;
    }
    @XmlAttribute(
            name = "DFHXJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhxjgdm() {
        return dfhxjgdm;
    }

    public void setDfhxjgdm(String dfhxjgdm) {
        this.dfhxjgdm = dfhxjgdm;
    }
    @XmlTransient
    public String getDfhxjgmc() {
        return dfhxjgmc;
    }

    public void setDfhxjgmc(String dfhxjgmc) {
        this.dfhxjgmc = dfhxjgmc;
    }
    @XmlAttribute(
            name = "DFFWYT1DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt1dm() {
        return dffwyt1dm;
    }

    public void setDffwyt1dm(String dffwyt1dm) {
        this.dffwyt1dm = dffwyt1dm;
    }
    @XmlTransient
    public String getDffwyt1mc() {
        return dffwyt1mc;
    }

    public void setDffwyt1mc(String dffwyt1mc) {
        this.dffwyt1mc = dffwyt1mc;
    }
    @XmlAttribute(
            name = "DFFWYT2DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt2dm() {
        return dffwyt2dm;
    }

    public void setDffwyt2dm(String dffwyt2dm) {
        this.dffwyt2dm = dffwyt2dm;
    }
    @XmlTransient
    public String getDffwyt2mc() {
        return dffwyt2mc;
    }

    public void setDffwyt2mc(String dffwyt2mc) {
        this.dffwyt2mc = dffwyt2mc;
    }
    @XmlAttribute(
            name = "DFFWYT3DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt3dm() {
        return dffwyt3dm;
    }

    public void setDffwyt3dm(String dffwyt3dm) {
        this.dffwyt3dm = dffwyt3dm;
    }
    @XmlTransient
    public String getDffwyt3mc() {
        return dffwyt3mc;
    }

    public void setDffwyt3mc(String dffwyt3mc) {
        this.dffwyt3mc = dffwyt3mc;
    }
}

==> estateplat-common-1.2.4-20201112.060606-496-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttFwHBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttFwH;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttFwHBdc extends KttFwH {
    private String dffwlxdm;
    private String dffwlxmc;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dfztdm;
    private String dfztmc;
    private String dfhxdm;
    private String dfhxmc;
    private String dfhxjgdm;
    private String dfhxjgmc;
    private String dffwyt1dm;
    private String dffwyt1mc;
    private String dffwyt2dm;
    private String dffwyt2mc;
    private String dffwyt3dm;
    private String dffwyt3mc;
    @XmlAttribute(
            name = "DFFWLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwlxdm() {
        return dffwlxdm;
    }

    public void setDffwlxdm(String dffwlxdm) {
        this.dffwlxdm = dffwlxdm;
    }
    @XmlAttribute(
            name = "DFFWLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwlxmc() {
        return dffwlxmc;
    }

    public void setDffwlxmc(String dffwlxmc) {
        this.dffwlxmc = dffwlxmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlAttribute(
            name = "DFFWXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxzmc) {
        this.dffwxzmc = dffwxzmc;
    }
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlAttribute(
            name = "DFZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
    @XmlAttribute(
            name = "DFHXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhxdm() {
        return dfhxdm;
    }

    public void setDfhxdm(String dfhxdm) {
        this.dfhxdm = dfhxdm;
    }
    @XmlAttribute(
            name = "DFHXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhxmc() {
        return dfhxmc;
    }

    public void setDfhxmc(String dfhxmc) {
        this.dfhxmc = dfhxmc;
    }
    @XmlAttribute(
            name = "DFHXJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhxjgdm() {
        return dfhxjgdm;
    }

    public void setDfhxjgdm(String dfhxjgdm) {
        this.dfhxjgdm = dfhxjgdm;
    }
    @XmlAttribute(
            name = "DFHXJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhxjgmc() {
        return dfhxjgmc;
    }

    public void setDfhxjgmc(String dfhxjgmc) {
        this.dfhxjgmc = dfhxjgmc;
    }
    @XmlAttribute(
            name = "DFFWYT1DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt1dm() {
        return dffwyt1dm;
    }

    public void setDffwyt1dm(String dffwyt1dm) {
        this.dffwyt1dm = dffwyt1dm;
    }
    @XmlAttribute(
            name = "DFFWYT1MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt1mc() {
        return dffwyt1mc;
    }

    public void setDffwyt1mc(String dffwyt1mc) {
        this.dffwyt1mc = dffwyt1mc;
    }
    @XmlAttribute(
            name = "DFFWYT2DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt2dm() {
        return dffwyt2dm;
    }

    public void setDffwyt2dm(String dffwyt2dm) {
        this.dffwyt2dm = dffwyt2dm;
    }
    @XmlAttribute(
            name = "DFFWYT2MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt2mc() {
        return dffwyt2mc;
    }

    public void setDffwyt2mc(String dffwyt2mc) {
        this.dffwyt2mc = dffwyt2mc;
    }
    @XmlAttribute(
            name = "DFFWYT3DM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt3dm() {
        return dffwyt3dm;
    }

    public void setDffwyt3dm(String dffwyt3dm) {
        this.dffwyt3dm = dffwyt3dm;
    }
    @XmlAttribute(
            name = "DFFWYT3MC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwyt3mc() {
        return dffwyt3mc;
    }

    public void setDffwyt3mc(String dffwyt3mc) {
        this.dffwyt3mc = dffwyt3mc;
    }
}
